﻿using ClientServer.Models.Users;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Threading.Tasks;
using ClientServer.Db;
using ClientServer.Models.Interfaces;

namespace ClientServer.Models.CustomProjects
{
    /// <summary>
    /// a custom project is like a exercise but was created by the user to do whatever
    /// 
    /// 
    /// why? if we want to open an exercise (e.g. because time used up) as an custom project (like a sandbox)
    /// then we have a nearly 1:1 mapping between an exercise and a custom project
    /// 
    /// this is also helpful if one day students can suggest exercises (--> 1:1 mapping)
    /// </summary>
    public class CustomProject //: IProject
    {

        public CustomProject()
        {
            Solutions = new List<CustomProjectSolution>();
            Tests = new List<CustomProjectTest>();
        }
        
        public int Id { get; set; }

        /// <summary>
        /// the name
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string DisplayName { get; set; }

        /// <summary>
        /// some description
        /// </summary>
        public CustomProjectDescription Description { get; set; }


        /// <summary>
        /// the last edited plang... set through the custom solution
        /// <see cref="Solutions"/>
        /// </summary>
        public int LastEditorPLangId { get; set; }
        
        
        /// <summary>
        /// list with solutions (for every p lang at most one)
        /// </summary>
        public List<CustomProjectSolution> Solutions { get; set; }
        
        
        public List<CustomProjectTest> Tests { get; set; }
        
        
        public DateTime LastUpdatedAt { get; set; }

        public int UserId { get; set; }
        /// <summary>
        /// the creator of this custom project
        /// </summary>
        public User User { get; set; }
    }
}
