﻿using System.ComponentModel.DataAnnotations;
using ClientServer.Db;

namespace ClientServer.Models.Exercises.Solution
{
    /// <summary>
    /// represents a file (one or multiple files are a solution)
    /// </summary>
    public class SolutionFile : ISolutionFile
    {
        public int Id { get; set; }
        /// <summary>
        /// the file name
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string FileNameWithExtension { get; set; }
        /// <summary>
        /// the content of the file
        /// </summary>
        [MaxLength(SyndromDbContext.FileContentMaxStringLength)]
        public string Content { get; set; }



        /// <summary>
        /// ui property, true: is displayed as tab, false: not (only displayed in project explorer)
        /// </summary>
        public bool IsDisplayed { get; set; }


        /// <summary>
        /// the order index how the file is displayed in the editor
        /// NOT USED YET
        /// </summary>
        public int DisplayIndex { get; set; }

        /// <summary>
        /// the connected tempalte file where this solution file was created from, or null if the user created this solution file
        /// </summary>
        public int? TemplateFileId { get; set; }
        /// <summary>
        /// the template file from which this solution part is created or null (if created by user)
        /// </summary>
        public TemplateFile TemplateFile { get; set; }
        
        
        //---added

        public int SolutionPLangId { get; set; }
        public int SolutionUserId { get; set; }
        public int SolutionExerciseReleaseId { get; set; }
        public Solution Solution { get; set; }

    }
}
