﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Threading.Tasks;
using ClientServer.Db;
using ClientServer.Models.Exercises.AfterSolutions;
using ClientServer.Models.Exercises.Release;
using ClientServer.Models.Exercises.Solution;
using ClientServer.Models.Users;
using Microsoft.EntityFrameworkCore.Metadata.Internal;

namespace ClientServer.Models.Exercises.Tests
{
    /// <summary>
    /// a test created by a user for an exercise
    /// </summary>
    public class CustomTest
    {
        public CustomTest()
        {
            TestAssets = new List<CustomTestAsset>();
            TestResultsNew = new List<CustomTestWithSingleSolutionAsTestResult>();
            AssetReferences = new  List<CustomTestWithFileAsAssetReference>();
        }


        public int Id { get; set; }
        /// <summary>
        /// the name
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string DisplayName { get; set; }
        /// <summary>
        /// the content for the <see cref="Test"/> ... see the black-box-test protocol
        /// </summary>
        [MaxLength(SyndromDbContext.TestContentMaxStringLength)]
        public string Content { get; set; }

        /// <summary>
        /// the index for the frontend sorting (>= 0, 0 is first, 1 second, ...)
        /// </summary>
        public int DisplayIndex { get; set; }

        /// <summary>
        /// all related assets for this test> e.g. a file to read
        /// </summary>
        public List<CustomTestAsset> TestAssets { get; set; }

        /// <summary>
        /// all related assets for this test> e.g. a file to read
        /// </summary>
        public List<CustomTestWithFileAsAssetReference> AssetReferences { get; set; }


        public int TestTypeId { get; set; }
        /// <summary>
        /// the connected <see cref="TestType"/>
        /// </summary>
        public TestType TestType { get; set; }



        //ForeignKey key

        //composite foreign key
        //pk
        public int ExerciseReleaseId { get; set; }

        //pk
        public int UserId { get; set; }

        
        //--- added
        
        public List<CustomTestWithSingleSolutionAsTestResult> TestResultsNew { get; set; }
        
        public List<CustomTestWithAfterSolutionAsTestResult> AfterTestResults { get; set; }
    }
}
