using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using ClientServer.Db;
using ClientServer.Helpers;
using ClientServer.Models.CustomProjects;
using ClientServer.Models.Exercises;

namespace ClientServer.Models.Files
{
    /// <summary>
    /// a reference to a file on the hard drive
    /// for user files (may be a custom test file, custom project test file, custom project description markdown asset)
    /// files are stored without an extension because we don't need to know
    /// </summary>
    public class FileReferenceUserFileAsset : IFileReference
    {
        public int Id { get; set; }

        public FileReferenceUserFileAsset()
        {
            CustomTestWithFileAsAssetReferences = new List<CustomTestWithFileAsAssetReference>();
            CustomProjectTestWithFileAsAssetReferences = new List<CustomProjectTestWithFileAsAssetReference>();
            CustomProjectDescriptionWithFileAsAssetReferences = new List<CustomProjectDescriptionWithFileAsAssetReference>();
        }

        /// <summary>
        /// md5 hash of the file content
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string Hash { get; set; }
        
        /// <summary>
        /// original name of the file (at the time the file was uploaded)
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string OriginalName { get; set; }
        
        /// <summary>
        /// the mime type (maybe we need to know what content is stored)
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string MimeType { get; set; }
        
        /// <summary>
        /// the size in bytes of the content (only set once)
        /// </summary>
        public long SizeInBytes { get; set; }

        public DateTime CreatedAt { get; set; }

        public DateTime LastUpdatedAt { get; set; }

        
        
        public List<CustomTestWithFileAsAssetReference> CustomTestWithFileAsAssetReferences { get; set; }

        public List<CustomProjectTestWithFileAsAssetReference> CustomProjectTestWithFileAsAssetReferences { get; set; }

        public List<CustomProjectDescriptionWithFileAsAssetReference> CustomProjectDescriptionWithFileAsAssetReferences { get; set; }

    }
}
