﻿using System.ComponentModel.DataAnnotations;
using ClientServer.Db;

namespace ClientServer.Models.Users
{
    /// <summary>
    /// an external user connected to an <see cref="User"/> to authenticate with an external system
    /// </summary>
    public class ExternalUser
    {
        /// <summary>
        /// the id from the external system
        /// </summary>
        public int ExternalId { get; set; }

        /// <summary>
        /// the token e.g. ahbxf or the username
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string Token { get; set; }
        /// <summary>
        /// the first name
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string FirstName { get; set; }

        /// <summary>
        /// the last name
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string LastName { get; set; }

        /// <summary>
        /// the email
        /// </summary>
        [MaxLength(SyndromDbContext.DefaultMaxStringLength)]
        public string Email { get; set; }
        /// <summary>
        /// true: the external data changed so when the next redirect comes then refresh the connected user data,
        /// false: all ok
        /// 
        /// CURRENTLY NOT IMPLEMENTED!!
        /// </summary>
        public bool NeedToRefreshData { get; set; }

        public int UserId { get; set; }
        /// <summary>
        /// the connected <see cref="User"/> if any
        /// </summary>
        public User User { get; set; }
    }
}
